@@ -1,4 +1,4 @@
-# $Id: grid.R 6 2006-01-06 11:52:37Z mentus $ 
+# $Id: grid.R 45 2008-05-23 15:50:48Z mentus $ 
 
 "HTMLgrid_summary" <- function(
     x,
@@ -78,7 +78,7 @@
 
 "HTMLgrid" <- function(
     x, 
-    file = .HTML.file, 
+    file = get(".HTML.file"), 
     append=TRUE ,
     includeref=FALSE,
     align="center", 
@@ -147,7 +147,7 @@
 
 "HTMLgrid_inline" <- function(
    x,
-   file = .HTML.file,
+   file = get(".HTML.file"),
    append=TRUE ,
    includeref=FALSE,
    align="center",
